@@ -1,17 +1,8 @@
 """
-Copyright (C) 2017 Roberto Bruttomesso <roberto.bruttomesso@gmail.com>
-
-This file is distributed under the terms of the 3-clause BSD License.
-A copy of the license can be found in the root directory or at
-https://opensource.org/licenses/BSD-3-Clause.
-
-Author: Roberto Bruttomesso <roberto.bruttomesso@gmail.com>
-  Date: 27/03/2017
-
 This module implements infrastructure to store datatypes
 """
 
-from intrepyd.lustre2py.visitable import Visitable
+from intrepyd.visitable import Visitable
 
 class Datatype(Visitable):
     """
@@ -45,22 +36,18 @@ class Array(Datatype):
     """
     Stores an array
     """
-    pass
 
 class Struct(Datatype):
     """
     Stores a struct
     """
-    pass
 
 class Enum(Datatype):
     """
     Stores an enum
     """
-    pass
 
 class Subrange(Datatype):
     """
     Stores a subrange
     """
-    pass
